@@ -33,71 +33,73 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-"""
-BaseImage: Provides basic image loading an manipulation with pygame
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.baseimage
+# Check if pygame exists, if not maybe the module is being used by setup.py
+__pygame_version__ = None
+try:
+    from pygame import version as __pygame_version__
 
-"""
-Controls: Default controls of menu object and key definition
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.controls
+    __pygame_version__ = __pygame_version__.vernum
+except (ModuleNotFoundError, ImportError):
+    pass
 
-"""
-Events: Menu events definition and locals
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.events
+# Import modules that require pygame
+if __pygame_version__ is not None:
+    """
+    BaseImage: Provides basic image loading an manipulation with pygame
+    """
+    import pygame_menu.baseimage
 
-"""
-Fonts: Menu fonts
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.font
+    """
+    Controls: Default controls of menu object and key definition
+    """
+    import pygame_menu.controls
 
-"""
-Locals: Local constants
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.locals
+    """
+    Events: Menu events definition and locals
+    """
+    import pygame_menu.events
 
-"""
-ScrollArea: Scrollarea class
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.scrollarea
+    """
+    Fonts: Menu fonts
+    """
+    import pygame_menu.font
 
-"""
-Sound: Sound class
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.sound
+    """
+    Locals: Local constants
+    """
+    import pygame_menu.locals
 
-"""
-Themes: Menu themes class
-"""
-# noinspection PyUnresolvedReferences
-import pygame_menu.themes
+    """
+    Menu: Menu class
+    """
+    # noinspection PyUnresolvedReferences
+    from pygame_menu.menu import Menu
+
+    """
+    ScrollArea: Scroll area class to manage scrolling in Menu
+    """
+    import pygame_menu.scrollarea
+
+    """
+    Sound: Sound class
+    """
+    import pygame_menu.sound
+
+    """
+    Themes: Menu themes
+    """
+    import pygame_menu.themes
+
+    """
+    Widgets: Menu widgets
+    """
+    import pygame_menu.widgets
 
 """
 Version: Library version
 """
-# noinspection PyUnresolvedReferences
 import pygame_menu.version
 
-"""
-Widgets: Menu widgets
-"""
-import pygame_menu.widgets
-
-"""
-Menu: Menu class
-"""
-# noinspection PyUnresolvedReferences
-from pygame_menu.menu import Menu
-
 """
 Metadata: Information about the project
 """
@@ -126,8 +128,9 @@ __description__ = 'A menu for pygame, simple, lightweight and easy to use'
 __email__ = 'pablo@ppizarror.com'
 __keywords__ = 'pygame menu menus gui widget input button pygame-menu'
 __license__ = 'MIT'
+__module_name__ = 'pygame-menu'
 __url__ = 'https://pygame-menu.readthedocs.io/en/latest/'
-__url_source_code__ = 'https://github.com/ppizarror/pygame-menu/tree/master/pygame_menu'
-__url_documentation__ = 'https://pygame-menu.readthedocs.io/en/latest/'
 __url_bug_tracker__ = 'https://github.com/ppizarror/pygame-menu/issues'
+__url_documentation__ = 'https://pygame-menu.readthedocs.io/en/latest/'
+__url_source_code__ = 'https://github.com/ppizarror/pygame-menu/tree/master/pygame_menu'
 __version__ = pygame_menu.version.ver
