@@ -33,12 +33,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-# Import libraries
-import sys
-
-sys.path.insert(0, '../../')
-
 import os
+
 import pygame
 import pygame_menu
 
@@ -48,8 +44,11 @@ import pygame_menu
 FPS = 60
 WINDOW_SIZE = (640, 480)
 
+# noinspection PyTypeChecker
 sound = None  # type: pygame_menu.sound.Sound
+# noinspection PyTypeChecker
 surface = None  # type: pygame.Surface
+# noinspection PyTypeChecker
 main_menu = None  # type: pygame_menu.Menu
 
 
