@@ -92,8 +92,6 @@ class Widget(object):
         self._margin = (0.0, 0.0)  # type: tuple
         self._max_width = None  # type: (int,float)
         self._padding = (0, 0, 0, 0)  # top, right, bottom, left
-        self._position_set = False
-        self._selected_rect = None  # type: (pygame.rect.Rect,None)
         self._selection_time = 0  # type: float
         self._title = to_string(title)
 
@@ -303,7 +301,9 @@ class Widget(object):
         This is a permanent change; for dynamic purpuoses, depending if the widget
         is selected or not, setting ``widget.selection_expand_background`` to ``True`` may help.
 
-        .. note:: This method may have unexpected results with certain selection effects.
+        .. note::
+
+            This method may have unexpected results with certain selection effects.
 
         :return: None
         """
@@ -337,7 +337,9 @@ class Widget(object):
         """
         Return the selection effect.
 
-        .. warning:: Use with caution.
+        .. warning::
+
+            Use with caution.
 
         :return: Selection effect
         :rtype: :py:class:`pygame_menu.widgets.core.Selection`
@@ -488,7 +490,9 @@ class Widget(object):
         - If 3-item tuple is provided: top will take the first value, left and right the second, and bottom the third
         - If 4-item tuple is provided: padding will be (top, right, bottom, left)
 
-        .. note:: See `CSS W3Schools <https://www.w3schools.com/css/css_padding.asp>`_ for more info about padding.
+        .. note::
+
+            See `CSS W3Schools <https://www.w3schools.com/css/css_padding.asp>`_ for more info about padding.
 
         :param padding: Can be a single number, or a tuple of 2, 3 or 4 elements following CSS style
         :type padding: int, float, tuple, list
@@ -540,8 +544,8 @@ class Widget(object):
         pad_bottom = self._padding[2] * apply_padding + inflate[1] / 2
         pad_left = self._padding[3] * apply_padding + inflate[0] / 2
 
-        return pygame.Rect(int(self._rect.x - pad_left),
-                           int(self._rect.y - pad_top),
+        return pygame.Rect(int(self._rect.x - pad_left + self._translate[0]),
+                           int(self._rect.y - pad_top + self._translate[1]),
                            int(self._rect.width + pad_left + pad_right),
                            int(self._rect.height + pad_bottom + pad_top))
 
@@ -753,7 +757,9 @@ class Widget(object):
         - ``selected_color``        Selected color (tuple)
         - ``size``                  Size of the font (int)
 
-        .. note:: If a key is not defined it will be rewritten using current font style from ``Widget.get_font_info()`` method.
+        .. note::
+
+            If a key is not defined it will be rewritten using current font style from ``Widget.get_font_info()`` method.
 
         :param style: Font style dict
         :type style: dict
@@ -813,7 +819,9 @@ class Widget(object):
         """
         Return the menu reference (if exists).
 
-        .. warning:: Use with caution.
+        .. warning::
+
+            Use with caution.
 
         :return: Menu reference
         :rtype: :py:class:`pygame_menu.Menu`, None
@@ -838,11 +846,10 @@ class Widget(object):
         :type posy: int, float
         :return: None
         """
-        if self._position_set and self.lock_position:
+        if self.lock_position:
             return
-        self._rect.x = posx + self._translate[0]
-        self._rect.y = posy + self._translate[1]
-        self._position_set = True
+        self._rect.x = int(posx)
+        self._rect.y = int(posy)
 
     def get_position(self):
         """
@@ -851,7 +858,7 @@ class Widget(object):
         :return: Widget position
         :rtype: tuple
         """
-        return self._rect.x, self._rect.y
+        return self._rect.x + self._translate[0], self._rect.y + self._translate[1]
 
     def get_width(self, apply_padding=True, apply_selection=False):
         """
@@ -937,7 +944,9 @@ class Widget(object):
         """
         Scale the widget to a desired width and height factor.
 
-        .. note:: Not all widgets are affected by scale.
+        .. note::
+
+            Not all widgets are affected by scale.
 
         :param width: Scale factor of the width
         :type width: int, float
@@ -980,7 +989,9 @@ class Widget(object):
         """
         Translate to *(+x,+y)* according to default position.
 
-        .. note:: To revert changes, only set to *(0,0)*.
+        .. note::
+
+            To revert changes, only set to *(0,0)*.
 
         :param x: +X in px
         :type x: int, float
@@ -1051,7 +1062,7 @@ class Widget(object):
 
     def get_selected_time(self):
         """
-        Return time the widget has been selected in miliseconds.
+        Return time the widget has been selected in milliseconds.
         If the widget is not currently selected, return 0.
 
         :return: Time in ms
@@ -1065,7 +1076,9 @@ class Widget(object):
         """
         Return widget surface.
 
-        .. warning:: Use with caution.
+        .. warning::
+
+            Use with caution.
 
         :return: Widget surface
         :rtype: :py:class:`pygame.Surface`
@@ -1268,7 +1281,9 @@ class Widget(object):
         After creating a new callback, this functions returns the ID of the call. It can be removed
         anytime using ``widget.remove_update_callback(id)``.
 
-        .. note:: Not all widgets are updated, so the provided function may never be executed.
+        .. note::
+
+            Not all widgets are updated, so the provided function may never be executed.
 
         :param update_callback: Function
         :type update_callback: callable
